==> wincachedrupal-8.x-1.0.tar.gz: wincachedrupal/src/KeyValueStorage/KeyValueWincacheExpirableFactory.php <==
<?php

/**
 * @file
 * Contains \Drupal\wincachedrupal\KeyValueStorage\KeyValueWincacheExpirableFactory.
 */

namespace Drupal\wincachedrupal\KeyValueStorage;

use Drupal\Component\Serialization\SerializationInterface;

use Drupal\Core\DestructableInterface;
use Drupal\Core\Database\Connection;

use Drupal\Core\KeyValueStore\KeyValueExpirableFactoryInterface;

/**
 * Defines the key/value store factory for the database backend.
 */
class KeyValueWincacheExpirableFactory implements KeyValueExpirableFactoryInterface {

  /**
   * Holds references to each instantiation so they can be terminated.
   *
   * @var \Drupal\Core\KeyValueStore\DatabaseStorageExpirable[]
   */
  protected $storages = array();

  /**
   * The serialization class to use.
   *
   * @var \Drupal\Component\Serialization\SerializationInterface
   */
  protected $serializer;

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * Constructs this factory object.
   *
   * @param \Drupal\Component\Serialization\SerializationInterface $serializer
   *   The serialization class to use.
   * @param \Drupal\Core\Database\Connection $connection
   *   The Connection object containing the key-value tables.
   */
  function __construct(SerializationInterface $serializer, Connection $connection) {
    $this->serializer = $serializer;
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public function get($collection) {
    if (!isset($this->storages[$collection])) {
      $this->storages[$collection] = new WincacheStorageExpirable($collection, $this->serializer, $this->connection);
    }
    return $this->storages[$collection];
  }

  /**
   * Deletes expired items.
   */
  public function garbageCollection() {
    // No need to gargabe collect.
  }
}

==> wincachedrupal-8.x-1.1.tar.gz: wincachedrupal/src/KeyValueStorage/KeyValueWincacheExpirableFactory.php <==
<?php

/**
 * @file
 * Contains \Drupal\wincachedrupal\KeyValueStorage\KeyValueWincacheExpirableFactory.
 */

namespace Drupal\wincachedrupal\KeyValueStorage;

use Drupal\Component\Serialization\SerializationInterface;

use Drupal\Core\DestructableInterface;
use Drupal\Core\Database\Connection;

use Drupal\Core\KeyValueStore\KeyValueExpirableFactoryInterface;

/**
 * Defines the key/value store factory for the wincache/databse backend.
 */
class KeyValueWincacheExpirableFactory implements KeyValueExpirableFactoryInterface {

  /**
   * Holds references to each instantiation so they can be terminated.
   *
   * @var \Drupal\Core\KeyValueStore\DatabaseStorageExpirable[]
   */
  protected $storages = array();

  /**
   * The serialization class to use.
   *
   * @var \Drupal\Component\Serialization\SerializationInterface
   */
  protected $serializer;

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * Constructs this factory object.
   *
   * @param \Drupal\Component\Serialization\SerializationInterface $serializer
   *   The serialization class to use.
   * @param \Drupal\Core\Database\Connection $connection
   *   The Connection object containing the key-value tables.
   */
  function __construct(SerializationInterface $serializer, Connection $connection) {
    $this->serializer = $serializer;
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public function get($collection) {
    if (!isset($this->storages[$collection])) {
      $this->storages[$collection] = new WincacheStorageExpirable($collection, $this->serializer, $this->connection);
    }
    return $this->storages[$collection];
  }

  /**
   * Deletes expired items.
   */
  public function garbageCollection() {
    // No need to gargabe collect.
  }
}
